PyXMake Developer Guide: PyXMake.Build.Make.Make Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.Make Class Reference

Abstract base class for all make objects. More...

Inheritance diagram for PyXMake.Build.Make.Make:

## Public Member Functions
def | __init__ (self, BuildID, Srcs, scratch=os.getcwd(), msvsc='vs2015', stype='Fortran', verbose=0, args, kwargs)
def | __getstate__ (self)
def | __setstate__ (self, _dict)
def | AddIncludePath (self, includes)
def | AddDependencyPath (self, dependencies)
def | UseLibraries (self, libs)
def | SourcePath (self, path)
def | OutputPath (self, path, files="")
def | Environment (self, path, script="ifortvars.bat")
def | Preprocessing
def | Build (self, cmdstring)
def | Postprocessing (self, cmdstring='')
def | create (self)

## Public Attributes
| buildid
| Base string of build object. More...
| srcs
| Source file or folders.
| stype
| Source file type.
| verbose
| Level of verbosity of the current build object. More...
| scrtdir
| Current scratch directory.
| srcdir
| Default search directory for source files. More...
| outdir
| Default search directory for output. More...
| intelpath
| Path to Intel Fortran Compiler (read from Paths.log). More...
| temps
| Tuple of data to be removed after job completion. More...
| incdirs
| List of include directories. More...
| libdirs
| List of library directories. More...
| libs
| List of actual libraries (by name) used during linking. More...
| copyfiles
| List of files to be copied to the output directory after finish. More...
| setarch
| Define the architecture for the build directly by using the keyword argument "arch". More...
| architecture
| Processor architecture.
| iniCompiler
| Executable batch script (including absolute system path) to set up the Intel Fortran Compiler. More...
| msvsc
| Default version of Microsoft visual studio used by the Intel Fortran Compiler. More...
| postcmd
| Post build command. More...
| buildname
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...

## Detailed Description

Abstract base class for all make objects.

    Parent class for all make objects.

Inherited from built-in ABCMeta & object. Compatible with both Python 2.x and 3.x.

Definition at line 67 of file Make.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Build.Make.Make.__init__ | ( |  | self,
|  |  | BuildID,
|  |  | Srcs,
|  |  | scratch = `os.getcwd()`,
|  |  | msvsc = `'vs2015'`,
|  |  | stype = `'Fortran'`,
|  |  | verbose = `0`,
|  |  | args,
|  |  | kwargs
| ) |  |

    Low-level initialization of parent class.

Definition at line 72 of file Make.py.

## Member Function Documentation

## ◆ __getstate__()

def PyXMake.Build.Make.Make.__getstate__ | ( |  | self | ) |

    Prepare the object for pickling (2to3 compatible)

Definition at line 173 of file Make.py.

## ◆ __setstate__()

def PyXMake.Build.Make.Make.__setstate__ | ( |  | self,
|  |  | _dict
| ) |  |

    Recover a dictionary from pickling (2to3 compatible)

Definition at line 180 of file Make.py.

## ◆ AddDependencyPath()

def PyXMake.Build.Make.Make.AddDependencyPath | ( |  | self,
|  |  | dependencies
| ) |  |

    Define additional directories containing 3rd party libraries as comma separated list.

Definition at line 196 of file Make.py.

## ◆ AddIncludePath()

def PyXMake.Build.Make.Make.AddIncludePath | ( |  | self,
|  |  | includes
| ) |  |

    Define additional include directories containing modules or source files as comma separated list.

Definition at line 188 of file Make.py.

## ◆ Build()

def PyXMake.Build.Make.Make.Build | ( |  | self,
|  |  | cmdstring
| ) |  |

    Assemble command string for the main build event.

Definition at line 314 of file Make.py.

## ◆ create()

def PyXMake.Build.Make.Make.create | ( |  | self | ) |

    Execute make command

Definition at line 349 of file Make.py.

## ◆ Environment()

def PyXMake.Build.Make.Make.Environment | ( |  | self,
|  |  | path,
|  |  | script = `"ifortvars.bat"`
| ) |  |

    Load an additional environment file prior to execution of all commands.

Definition at line 229 of file Make.py.

## ◆ OutputPath()

def PyXMake.Build.Make.Make.OutputPath | ( |  | self,
|  |  | path,
|  |  | files = `""`
| ) |  |

    Define a new output directory. Output is written to the workspace by default.

Definition at line 219 of file Make.py.

## ◆ Postprocessing()

def PyXMake.Build.Make.Make.Postprocessing | ( |  | self,
|  |  | cmdstring = `''`
| ) |  |

    Assemble command string for the post-build event.

Definition at line 341 of file Make.py.

## ◆ SourcePath()

def PyXMake.Build.Make.Make.SourcePath | ( |  | self,
|  |  | path
| ) |  |

    Define a new source directory. Input is read from workspace by default.

Definition at line 212 of file Make.py.

## ◆ UseLibraries()

def PyXMake.Build.Make.Make.UseLibraries | ( |  | self,
|  |  | libs
| ) |  |

    Define which non-default libraries should be used during linking.

Definition at line 204 of file Make.py.

## Member Data Documentation

## ◆ buildid

PyXMake.Build.Make.Make.buildid

Base string of build object.

Defines the base string of the current build object. The final build name used in the instanced objects is assembled using this immutable base id.

Definition at line 79 of file Make.py.

## ◆ compargs

PyXMake.Build.Make.Make.compargs

Command line arguments passed in by the user.

Definition at line 336 of file Make.py.

## ◆ copyfiles

PyXMake.Build.Make.Make.copyfiles

List of files to be copied to the output directory after finish.

List of files copied to the output directory.

Definition at line 122 of file Make.py.

## ◆ incdirs

PyXMake.Build.Make.Make.incdirs

List of include directories.

Definition at line 114 of file Make.py.

## ◆ iniCompiler

PyXMake.Build.Make.Make.iniCompiler

Executable batch script (including absolute system path) to set up the Intel Fortran Compiler.

Definition at line 145 of file Make.py.

## ◆ intelpath

PyXMake.Build.Make.Make.intelpath

Path to Intel Fortran Compiler (read from Paths.log).

Execute an additional bash script prior to all build commands.

Definition at line 106 of file Make.py.

## ◆ libdirs

PyXMake.Build.Make.Make.libdirs

List of library directories.

Definition at line 116 of file Make.py.

## ◆ libs

PyXMake.Build.Make.Make.libs

List of actual libraries (by name) used during linking.

Definition at line 118 of file Make.py.

## ◆ makecmd

PyXMake.Build.Make.Make.makecmd

Command executed during build event.

Definition at line 338 of file Make.py.

## ◆ msvsc

PyXMake.Build.Make.Make.msvsc

Default version of Microsoft visual studio used by the Intel Fortran Compiler.

Defaults to 'vs2010'.

Definition at line 151 of file Make.py.

## ◆ outdir

PyXMake.Build.Make.Make.outdir

Default search directory for output.

Definition at line 99 of file Make.py.

## ◆ postcmd

PyXMake.Build.Make.Make.postcmd

Post build command.

Command executed during post-build event.

Defaults to an empty string.

Definition at line 155 of file Make.py.

## ◆ precmd

PyXMake.Build.Make.Make.precmd

Command executed during pre-build event.

Definition at line 308 of file Make.py.

## ◆ setarch

PyXMake.Build.Make.Make.setarch

Define the architecture for the build directly by using the keyword argument "arch".

Defaults to None, in which case the architecture is determined by using the python executable.

Definition at line 126 of file Make.py.

## ◆ srcdir

PyXMake.Build.Make.Make.srcdir

Default search directory for source files.

Definition at line 97 of file Make.py.

## ◆ temps

PyXMake.Build.Make.Make.temps

Tuple of data to be removed after job completion.

Absolute system path of MKL library.

Definition at line 110 of file Make.py.

## ◆ verbose

PyXMake.Build.Make.Make.verbose

Level of verbosity of the current build object.

Define the verbosity level of the current build object. Defaults to 0 and suppresses all outputs to the command line. A higher value increases the level of verbosity up to a maximum level of 2.

Definition at line 90 of file Make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Build/Make.py